<?php
/**
 * Product quantity inputs
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/quantity-input.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.4.0
 *
 * @var bool   $readonly If the input should be set to readonly mode.
 * @var string $type     The input type attribute.
 */


defined( 'ABSPATH' ) || exit;

if($max_value && $min_value === $max_value) {
?>
<div class="quantity hidden">
	<input type="hidden" id="<?php echo esc_attr( $input_id ); ?>" class="qty" name="<?php echo esc_attr( $input_name ); ?>" value="<?php echo esc_attr( $min_value ); ?>" />
</div>
<?php
} else {
    
/* translators: %s: Quantity. */
$label = ! empty( $args['product_name'] ) ? sprintf( esc_html__( '%s quantity', 'inland' ), wp_strip_all_tags( $args['product_name'] ) ) : esc_html__( 'Quantity', 'inland');
?>
<div class="product-qyt-wrapper">
      <div class="product-qyt">
          <div class="quantity">
            <label class="screen-reader-text" for="<?php echo esc_attr( $input_id ); ?>">
            <?php esc_html_e( 'Quantity', 'inland' ); ?></label>
           
            <input
                type="number"
                id="<?php echo esc_attr( $input_id ); ?>"
                class="input-text qty text"
                step="<?php echo esc_attr( $step ); ?>"
                min="<?php echo esc_attr( $min_value ); ?>"
                max="<?php echo esc_attr( 0 < $max_value ? $max_value : '100' ); ?>"
                name="<?php echo esc_attr( $input_name ); ?>"
                value="<?php echo esc_attr( $input_value ); ?>"
                title="<?php echo esc_attr_x( 'Qty', 'Product quantity input tooltip', 'inland' ); ?>"
                inputmode="<?php echo esc_attr( $inputmode ); ?>"
                aria-labelledby="<?php echo esc_attr( $labelledby ); ?>" />
                <div class="it-product-quantity">
                 <button type="button" class="qty-button plus" >
                     <svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 256 256" xml:space="preserve">
	                 <g><g>
                	  <polygon points="128,48.907 0,176.907 30.187,207.093 128,109.28 225.813,207.093 256,176.907"/>
                	</g></g>
                    </svg>
                 </button>
                 <button type="button" class="qty-button minus" >
                    <svg version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px" viewBox="0 0 256 256" xml:space="preserve">
	                  <g>
                    	<g>
                    	<polygon points="225.813,48.907 128,146.72 30.187,48.907 0,79.093 128,207.093 256,79.093 		"/>
                    	</g>
                      </g>
                    </svg>
                 </button>
                </div>
        	</div>
        </div>
</div>
<?php
}
